[qet] qet/qet: [5262] Fix some Debian lintian spelling errors

[ Thread Index | Date Index | More lists.tuxfamily.org/qet Archives ]


Revision: 5262
Author:   scorpio810
Date:     2018-03-11 14:38:41 +0100 (Sun, 11 Mar 2018)
Log Message:
-----------
Fix some Debian lintian spelling errors

Modified Paths:
--------------
    trunk/ChangeLog
    trunk/sources/ElementsCollection/elementcollectionhandler.cpp
    trunk/sources/editor/qetelementeditor.cpp
    trunk/sources/qet.cpp
    trunk/sources/qetproject.cpp
    trunk/sources/qetxml.cpp
    trunk/sources/titleblock/qettemplateeditor.cpp
    trunk/sources/titleblock/templatescollection.cpp

Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/ChangeLog	2018-03-11 13:38:41 UTC (rev 5262)
@@ -7,7 +7,7 @@
 * User can export / import the configuration of the texts and texts group of an element.
 * Element editor : element informations (manufacturer, reference etc...) can be created directly from the element editor. For that go to the widget "Element Property"
 * Element editor : it is no longer required to have a text field, for save the edited element.
-* Fix crash occured by the conductor and shape "ghost".
+* Fix crash occurred by the conductor and shape "ghost".
 * Dissociate fonts policy and size for independent text item and for summarry pages (foliolist), add a 2 button in config page for open Qfontdialog widget and choose policy for independent text item
 Possiblility to overide defaut settings by adding in QElectroTech.conf
 * Basic shape add new CustomDashLine style with Dash Pattern (<< 10 << 10 );

Modified: trunk/sources/ElementsCollection/elementcollectionhandler.cpp
===================================================================
--- trunk/sources/editor/qetelementeditor.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/editor/qetelementeditor.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -688,7 +688,7 @@
 /**
  * @brief QETElementEditor::checkElement
  * Do several check about element.
- * If error is occured return false
+ * If error is occurred return false
  */
 bool QETElementEditor::checkElement()
 {
@@ -1135,7 +1135,7 @@
 /**
  * @brief QETElementEditor::slot_save
  * Save the current editing element.
- * If the filepath or location is unknow, use save_as instead
+ * If the filepath or location is unknown, use save_as instead
  * @return true if save with success
  */
 bool QETElementEditor::slot_save()

Modified: trunk/sources/qet.cpp
===================================================================
--- trunk/sources/qet.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/qet.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -554,7 +554,7 @@
 	@param filepath Path to the file to be written
 	@param error_message If non-zero, will contain an error message explaining
 	what happened when this function returns false.
-	@return false if an error occured, true otherwise
+	@return false if an error occurred, true otherwise
 */
 bool QET::writeXmlFile(QDomDocument &xml_doc, const QString &filepath, QString *error_message) {
 	QFile file(filepath);

Modified: trunk/sources/qetproject.cpp
===================================================================
--- trunk/sources/qetproject.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/qetproject.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -957,7 +957,7 @@
 	Integrate a title block template into this project.
 	@param src_tbt The location of the title block template to be integrated into this project
 	@param handler 
-	@return the name of the template after integration, or an empty QString if a problem occured.
+	@return the name of the template after integration, or an empty QString if a problem occurred.
 */
 QString QETProject::integrateTitleBlockTemplate(const TitleBlockTemplateLocation &src_tbt, MoveTitleBlockTemplatesHandler *handler) {
 	TitleBlockTemplateLocation dst_tbt(src_tbt.name(), &titleblocks_);

Modified: trunk/sources/qetxml.cpp
===================================================================
--- trunk/sources/qetxml.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/qetxml.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -40,7 +40,7 @@
 		case Qt::DashDotLine    : style = "DashDotLine";    break;
 		case Qt::DashDotDotLine : style = "DashDotDotLine"; break;
 		case Qt::CustomDashLine : style = "CustomDashLine"; break;
-		default                 : style = "Unknow";         break;
+		default                 : style = "Unknown";         break;
 	}
 
 	element.setAttribute("style", style);
@@ -110,7 +110,7 @@
 		case Qt::BDiagPattern     : style = "BDiagPattern";     break;
 		case Qt::FDiagPattern     : style = "FDiagPattern";     break;
 		case Qt::DiagCrossPattern : style = "DiagCrossPattern"; break;
-		default                   : style = "Unknow";           break;
+		default                   : style = "Unknown";           break;
 	}
 
 	element.setAttribute("style", style);
@@ -147,7 +147,7 @@
 	else if (style == "BDiagPattern")     brush.setStyle(Qt::BDiagPattern);
 	else if (style == "FDiagPattern")     brush.setStyle(Qt::FDiagPattern);
 	else if (style == "DiagCrossPattern") brush.setStyle(Qt::DiagCrossPattern);
-	else if (style == "Unknow")           brush.setStyle(Qt::NoBrush);
+	else if (style == "Unknown")          brush.setStyle(Qt::NoBrush);
 
 	brush.setColor(QColor(element.attribute("color", "#000000")));
 	return brush;
@@ -230,7 +230,7 @@
  * @param xml_document : An XML document to be exported
  * @param file_path : Path to the file to be written
  * @param error_message : If non-zero, will contain an error message explaining what happened when this function returns false.
- * @return false if an error occured, true otherwise
+ * @return false if an error occurred, true otherwise
  */
 bool QETXML::writeXmlFile(const QDomDocument &xml_document, const QString &file_path, QString *error_message)
 {

Modified: trunk/sources/titleblock/qettemplateeditor.cpp
===================================================================
--- trunk/sources/titleblock/qettemplateeditor.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/titleblock/qettemplateeditor.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -242,7 +242,7 @@
 
 /**
 	@param file_path Path of the template file to edit.
-	@return false if a problem occured while opening the template, true otherwise.
+	@return false if a problem occurred while opening the template, true otherwise.
 */
 bool QETTitleBlockTemplateEditor::edit(const QString &file_path) {
 	// get title block template object from the file, edit it
@@ -268,7 +268,7 @@
 
 /**
 	@param tbt Title block template to be edited
-	@return false if a problem occured while opening the template, true otherwise.
+	@return false if a problem occurred while opening the template, true otherwise.
 */
 bool QETTitleBlockTemplateEditor::editCopyOf(const TitleBlockTemplate *tbt) {
 	if (!tbt) return(false);
@@ -277,7 +277,7 @@
 
 /**
 	@param tbt Title block template to be directly edited
-	@return false if a problem occured while opening the template, true otherwise.
+	@return false if a problem occurred while opening the template, true otherwise.
 */
 bool QETTitleBlockTemplateEditor::edit(TitleBlockTemplate *tbt) {
 	if (!tbt) return(false);

Modified: trunk/sources/titleblock/templatescollection.cpp
===================================================================
--- trunk/sources/titleblock/templatescollection.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/titleblock/templatescollection.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -229,7 +229,7 @@
 	existing one.
 	@param xml_elmt An \<titleblocktemplate\> XML element describing the
 	template. Its "name" attribute must equal to template_name.
-	@return false if a problem occured, true otherwise
+	@return false if a problem occurred, true otherwise
 */
 bool TitleBlockTemplatesProjectCollection::setTemplateXmlDescription(const QString &template_name, const QDomElement &xml_elmt) {
 	// check basic stuff


Mail converted by MHonArc 2.6.19+ http://listengine.tuxfamily.org/
--- trunk/sources/ElementsCollection/elementcollectionhandler.cpp	2018-03-11 13:10:49 UTC (rev 5261)
+++ trunk/sources/ElementsCollection/elementcollectionhandler.cpp	2018-03-11 13:38:41 UTC (rev 5262)
@@ -321,7 +321,7 @@
  * @param parent : parent of the dir to create
  * @param name : name of directorie to create
  * @param name_list : translations of the directorie name
  * @return : ElementsLocation that represent the new directorie, location can be null if an error was occured
  */
 ElementsLocation ElementCollectionHandler::createDir(ElementsLocation &parent, const QString &name, const NamesList &name_list)
 {
@@ -357,7 +357,7 @@
 			return created_dir;
 		}
 		else {
-			qDebug() << "ElementCollectionHandler::createDir : error was occured at creation of new directories in file system. ";
+			qDebug() << "ElementCollectionHandler::createDir : error was occurred at creation of new directories in file system. ";
 			return ElementsLocation();
 		}
 	}
@@ -367,7 +367,7 @@
 			return created_dir;
 		}
 		else {
-			qDebug() << "ElementCollectionHandler::createDir : error was occured at creation of new directories in embbeded collection.";
+			qDebug() << "ElementCollectionHandler::createDir : error was occurred at creation of new directories in embbeded collection.";
 			return ElementsLocation();
 		}
 	}
@@ -321,7 +321,7 @@
  * @param name : name of directorie to create
  * @param name_list : translations of the directorie name
- * @return : ElementsLocation that represent the new directorie, location can be null if an error was occured
+ * @return : ElementsLocation that represent the new directorie, location can be null if an error was occurred
  */
 ElementsLocation ElementCollectionHandler::createDir(ElementsLocation &parent, const QString &name, const NamesList &name_list)

Modified: trunk/sources/editor/qetelementeditor.cpp
===================================================================